#!/usr/bin/python

import warnings
warnings.filterwarnings("ignore", "apt API not stable yet", FutureWarning)
import apt
import string
import sys

cache = apt.Cache()

for fname in sys.argv[1:]:
    
    # get the packagename
    content = []
    for line in open(fname):
        content.append(line)
        if line.startswith("X-AppInstall-Package"):
            pkgname = line.split("=")[1].strip()

    # calc the gst elements
    pkg = cache[pkgname]
    if not pkg.candidate.record:
        continue
    s = str(pkg.candidate.record)
    encoder=[]
    decoder=[]
    element=[]
    urisource=[]
    version=""
    for line in s.split("\n"):
        # skip lines that are not key/value
        if line == "" or line.startswith(" ") or line.startswith("\t"):
            continue
        line = line.rstrip()
        # split string
        (key, value) = string.split(line, ":", maxsplit=1)
        if key == "Gstreamer-Decoders":
            decoder = value.split(";")
        elif key == "Gstreamer-Elements":
            element = value.split(",")
        elif key == "Gstreamer-Encoders":
            encoder = value.split(";")
        elif key == "Gstreamer-Uri-Sources":
            urisource = value.split(",")
        elif key == "Gstreamer-Version":
            version = value.strip()
    # skip if we don't have a version
    if not version:
        print "WARNING: no g-s-t data for %s" % pkgname
        continue
    # gen output string
    s=""
    for elm in encoder:
        s+="%s:encoder-%s;" % (version, elm.strip())
    for elm in decoder:
        s+="%s:decoder-%s;" % (version, elm.strip())
    for elm in element:
        s+="%s:element-%s;" % (version, elm.strip())
    for elm in urisource:
        s+="%s:urisource-%s;" % (version, elm.strip())
    
    # write it back
    out = open(fname,"w")
    for line in content:
        if line.startswith("X-AppInstall-Codecs"):
            line="X-AppInstall-Codecs=%s\n" % s
        out.write(line)
    



#!/usr/bin/env python
# (c) 2005-2007 Canonical, GPL
# Authors:
#  Michael Vogt


import os
import sys
import glob
import urllib
from optparse import OptionParser


def downloadPopcon(uri, destfile):
    print "Downloading popcon data"
    res = urllib.urlretrieve(uri, destfile)
    #print res


def extractPopconData(filename):
    res = {}
    for line in open(filename):
        if line.startswith("#"):
            continue
        # we split until we reach the "------" line where we stop
        try:
            (rank, name, inst, vote, old, recent, files, maint) = line.split(None,7)
            # mvo: we use inst as the indicator (because we do not have enough
            #      data to use vote
            res[name] = vote
        except ValueError:
            break
    return res

def mergePopconData(menudir, popcon_data):
    for dentry in glob.glob("%s/*.desktop" % menudir):
        pkgname = None
        for line in open(dentry):
            if line.startswith("X-AppInstall-Package"):
                pkgname = line.strip().split("=")[1]
                if not popcon_data.has_key(pkgname):
                    print "WARNING: no popcon data for '%s'" % pkgname
                    pkgname = None
        if not pkgname is None:
            print "Updating '%s' with popcon data for '%s'" % (dentry,pkgname)
            content = []
            for line in open(dentry):
                if not line.startswith("X-AppInstall-Popcon="):
                    content.append(line)
                if line.startswith("X-AppInstall-Package"):
                    content.append("X-AppInstall-Popcon=%s\n" % popcon_data[pkgname])
            if not content[-1].endswith("\n"):
                content[-1] += "\n"
            f = open(dentry,"w")
            f.write("".join(content))
            f.close()

if __name__ == "__main__":
    parser = OptionParser()
    parser.add_option("-v", "--verbose", dest="verbose",
                      action="store_true", default="False",
                      help="be verbose")
    parser.add_option("-p", "--popcon-uri", dest="popcon_uri",
                      default="http://popcon.ubuntu.com/by_vote",
                      help="download location for the popcon data")
    parser.add_option("-d", "--direcroty", dest="dir",
                      default="../menu-data",
                      help="directory for the menu-data")
    (options, args) = parser.parse_args()

    # filename
    popcon = "popcon_data.txt"
    # download it
    downloadPopcon(options.popcon_uri, popcon)

    # extract the data, popcon data is a dictionary with
    # (pkgname -> value) where big values are better
    popcon_data = extractPopconData(popcon)

    # merge popcon data
    mergePopconData(options.dir, popcon_data)
    

    



#!/usr/bin/python
# quick script to check which desktop files refer to packages that are no longer in the cache
# beware that apps only available on i386, but not on amd64 are also listed when running on amd64

import glob
import os
import sys

from apt.cache import Cache
from glob import glob

if len(sys.argv) < 2:
    basepath = "."
else:
    basepath = sys.argv[1]

cache = Cache()
cache.open()

pkg_count = 0

for entry in os.listdir(basepath):
    # we only care for folders that start with menu-data
    if not (entry.startswith("menu-data") and
            os.path.isdir(os.path.join(basepath, entry))):
        continue
    # now check all the desktop files in there
    for desktop_file_path in glob(os.path.join(basepath, entry,"*.desktop")):
        pkgname = None
        component = None
        for line in open(desktop_file_path):
            if line.startswith("X-AppInstall-Package="):
                pkgname = line[len("X-AppInstall-Package="):].strip('\n')
            elif line.startswith("X-AppInstall-Section="):
                component = line[len("X-AppInstall-Section="):].strip('\n')
        try:
            pkg = cache[pkgname]
            if not "/" in pkg.section:
                pkg_component = "main"
            else:
                pkg_component = pkg.section.split("/")[0]
            if pkg_component != component:
                print "%s: component mismatch pkg=%s vs meta=%s" % (
                    desktop_file_path, pkg_component, component)
        except KeyError:
            pkg_count += 1
            print "not in cache: %s" % desktop_file_path

print str(pkg_count) + " desktop files can be removed."



#!/usr/bin/python

import os
import subprocess
import sys


# FIXME: calculate this automatically from software-centers dependencies
DEPENDANT_ICON_THEMES = ["humanity-icon-theme",
                         "gnome-icon-theme",
                         "hicolor-icon-theme",
                         ]

if __name__ == "__main__":
    
    icondir = sys.argv[1]
    
    icons_in_icontheme = set()
    # gather data from the icon themes we have
    for pkgname in DEPENDANT_ICON_THEMES:
        output = subprocess.check_output(["dpkg", "-L", pkgname])
        for line in output.split("\n"):
            if not line.startswith("/usr/share/icons"):
                continue
            iconname = os.path.basename(line)
            icons_in_icontheme.add(iconname)

    # now go over icondir
    seen = set()
    for f in os.listdir(icondir):
        if f in icons_in_icontheme:
            print "in icontheme: ", f
        if os.path.splitext(f)[0] in seen:
            print "duplicated: ", f
        seen.add(os.path.splitext(f)[0])

